summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorgokhale <asgokhale@users.noreply.github.com>1997-06-26 15:06:19 +0000
committergokhale <asgokhale@users.noreply.github.com>1997-06-26 15:06:19 +0000
commit3887caddabf0be7b9b3c78212a4632f51ecc725b (patch)
tree923037f02ca0d8d5a4bb746538f36f4b41bb6858
parent502c07f9daf07956fd48c991866ba69327269ad9 (diff)
downloadATCD-3887caddabf0be7b9b3c78212a4632f51ecc725b.tar.gz
More progress, nothing significant though.
-rw-r--r--TAO/TAO_IDL/ChangeLog5
-rw-r--r--TAO/TAO_IDL/Makefile6
-rw-r--r--TAO/TAO_IDL/ast/Makefile2
-rw-r--r--TAO/TAO_IDL/be/Makefile189
-rw-r--r--TAO/TAO_IDL/be/be_generator.cpp10
-rw-r--r--TAO/TAO_IDL/be/be_helper.cpp64
-rw-r--r--TAO/TAO_IDL/be/be_interface.cpp14
-rw-r--r--TAO/TAO_IDL/be/be_produce.cpp37
-rw-r--r--TAO/TAO_IDL/be/be_root.cpp152
-rw-r--r--TAO/TAO_IDL/be_include/be.h1
-rw-r--r--TAO/TAO_IDL/be_include/be_generator.h5
-rw-r--r--TAO/TAO_IDL/be_include/be_helper.h79
-rw-r--r--TAO/TAO_IDL/be_include/be_interface.h8
-rw-r--r--TAO/TAO_IDL/be_include/be_root.h51
-rw-r--r--TAO/TAO_IDL/driver/Makefile2
-rw-r--r--TAO/TAO_IDL/fe/Makefile5
-rw-r--r--TAO/TAO_IDL/include/idl_global.h1
-rw-r--r--TAO/TAO_IDL/narrow/Makefile2
-rw-r--r--TAO/TAO_IDL/util/Makefile2
-rw-r--r--TAO/TAO_IDL/util/utl_global.cpp12
20 files changed, 600 insertions, 47 deletions
diff --git a/TAO/TAO_IDL/ChangeLog b/TAO/TAO_IDL/ChangeLog
index b43c5abd2b5..13ca4796816 100644
--- a/TAO/TAO_IDL/ChangeLog
+++ b/TAO/TAO_IDL/ChangeLog
@@ -1,3 +1,8 @@
+Thu Jun 26 10:02:47 1997 Aniruddha Gokhale <gokhale@merengue.cs.wustl.edu>
+
+ * Some more progress. Generates the client and server side files
+ without much contents in it.
+
Sat May 17 17:18:38 1997 Aniruddha Gokhale <gokhale@mambo.cs.wustl.edu>
* First pass at providing a backend to the SunSoft's CORBA IDL
diff --git a/TAO/TAO_IDL/Makefile b/TAO/TAO_IDL/Makefile
index 5ef9a3ab1ad..5284ed615a5 100644
--- a/TAO/TAO_IDL/Makefile
+++ b/TAO/TAO_IDL/Makefile
@@ -11,7 +11,7 @@
INFO =
DIRS = driver fe ast util narrow be
BIN = tao
-LIBS = -ldrv -lfe -last -lutil -lnarrow -lbe
+TAOLIBS = -ldrv -lfe -last -lutil -lnarrow -lbe
CLONE =
#----------------------------------------------------------------------------
@@ -29,7 +29,9 @@ include $(WRAPPER_ROOT)/include/makeinclude/rules.nolocal.GNU
#----------------------------------------------------------------------------
all:
- $(CXX) -g -o tao $(LIBS) -lthread
+ cp ./driver/libdrv.so ./fe/libfe.so ./ast/libast.so ./util/libutil.so \
+ ./narrow/libnarrow.so ./be/libbe.so /project/mambo/gokhale/lib
+ $(CXX) -g -o tao $(TAOLIBS) $(LIBS) -lthread
tags:
rm -f TAGS
diff --git a/TAO/TAO_IDL/ast/Makefile b/TAO/TAO_IDL/ast/Makefile
index 2747041876c..6d08c459886 100644
--- a/TAO/TAO_IDL/ast/Makefile
+++ b/TAO/TAO_IDL/ast/Makefile
@@ -53,7 +53,7 @@ LDLIBS = -last
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
diff --git a/TAO/TAO_IDL/be/Makefile b/TAO/TAO_IDL/be/Makefile
index b3ab1a2bb8a..09584f48895 100644
--- a/TAO/TAO_IDL/be/Makefile
+++ b/TAO/TAO_IDL/be/Makefile
@@ -12,6 +12,7 @@ IDL_CFE_VERSION = \"1.3.0\"
# These are components that are sources of
BE_FILES = \
+ be_helper \
be_array \
be_argument \
be_attribute \
@@ -26,6 +27,7 @@ BE_FILES = \
be_module \
be_operation \
be_predefined_type \
+ be_root \
be_sequence \
be_string \
be_structure \
@@ -37,8 +39,7 @@ BE_FILES = \
be_generator \
be_init \
be_produce \
- be_args \
- be_helper
+ be_args
FILES = $(BE_FILES)
@@ -51,7 +52,7 @@ LDLIBS = -lbe
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
# Include macros and targets
@@ -115,7 +116,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_argument.o .shobj/be_argument.so: be_argument.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -153,7 +155,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_attribute.o .shobj/be_attribute.so: be_attribute.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -191,7 +194,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_constant.o .shobj/be_constant.so: be_constant.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -229,7 +233,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_enum.o .shobj/be_enum.so: be_enum.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -267,7 +272,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_enum_val.o .shobj/be_enum_val.so: be_enum_val.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -305,7 +311,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_exception.o .shobj/be_exception.so: be_exception.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -343,7 +350,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_expression.o .shobj/be_expression.so: be_expression.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -381,7 +389,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_field.o .shobj/be_field.so: be_field.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -419,7 +428,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_interface.o .shobj/be_interface.so: be_interface.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -457,7 +467,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_interface_fwd.o .shobj/be_interface_fwd.so: be_interface_fwd.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -495,7 +506,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_module.o .shobj/be_module.so: be_module.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -533,7 +545,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_operation.o .shobj/be_operation.so: be_operation.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -571,7 +584,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_predefined_type.o .shobj/be_predefined_type.so: be_predefined_type.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -609,7 +623,47 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
+.obj/be_root.o .shobj/be_root.so: be_root.cpp ../include/idl.h ../include/intlmacros.h \
+ ../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
+ ../include/idl_bool.h ../include/utl_string.h \
+ ../include/utl_identifier.h ../include/ast.h \
+ ../include/utl_scoped_name.h ../include/ast_decl.h \
+ ../include/ast_expression.h ../include/utl_scope.h \
+ ../include/ast_type.h ../include/ast_concrete_type.h \
+ ../include/ast_predefined_type.h ../include/ast_module.h \
+ ../include/ast_root.h ../include/ast_interface.h \
+ ../include/ast_interface_fwd.h ../include/ast_structure.h \
+ ../include/ast_exception.h ../include/ast_enum.h \
+ ../include/ast_operation.h ../include/utl_list.h \
+ ../include/ast_field.h ../include/ast_argument.h \
+ ../include/ast_attribute.h ../include/ast_union.h \
+ ../include/ast_union_branch.h ../include/ast_union_label.h \
+ ../include/ast_constant.h ../include/ast_enum_val.h \
+ ../include/ast_array.h ../include/ast_sequence.h \
+ ../include/ast_string.h ../include/ast_typedef.h \
+ ../include/utl_strlist.h ../include/utl_exprlist.h \
+ ../include/ast_generator.h ../include/util.h ../include/utl_stack.h \
+ ../include/utl_idlist.h ../include/utl_exceptlist.h \
+ ../include/utl_namelist.h ../include/utl_labellist.h \
+ ../include/utl_decllist.h ../include/idl_global.h \
+ ../include/utl_error.h ../include/utl_indenter.h \
+ ../include/idl_extern.h ../include/fe_extern.h ../include/be_extern.h \
+ ../include/drv_extern.h ../include/ast_extern.h \
+ ../include/nr_extern.h ../include/global_extern.h ../be_include/be.h \
+ ../be_include/be_generator.h ../be_include/be_predefined_type.h \
+ ../be_include/be_module.h ../be_include/be_interface.h \
+ ../be_include/be_interface_fwd.h ../be_include/be_structure.h \
+ ../be_include/be_exception.h ../be_include/be_expression.h \
+ ../be_include/be_enum.h ../be_include/be_operation.h \
+ ../be_include/be_field.h ../be_include/be_argument.h \
+ ../be_include/be_attribute.h ../be_include/be_union.h \
+ ../be_include/be_union_branch.h ../be_include/be_union_label.h \
+ ../be_include/be_constant.h ../be_include/be_enum_val.h \
+ ../be_include/be_array.h ../be_include/be_sequence.h \
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_sequence.o .shobj/be_sequence.so: be_sequence.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -647,7 +701,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_string.o .shobj/be_string.so: be_string.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -685,7 +740,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_structure.o .shobj/be_structure.so: be_structure.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -723,7 +779,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_typedef.o .shobj/be_typedef.so: be_typedef.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -761,7 +818,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_union.o .shobj/be_union.so: be_union.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -799,7 +857,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_union_branch.o .shobj/be_union_branch.so: be_union_branch.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -837,7 +896,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_union_label.o .shobj/be_union_label.so: be_union_label.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -875,7 +935,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_generator.o .shobj/be_generator.so: be_generator.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -913,7 +974,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_generator.o .shobj/be_generator.so: be_generator.cpp ../include/idl.h \
../include/intlmacros.h ../include/idl_narrow.h \
../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
@@ -951,7 +1013,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_init.o .shobj/be_init.so: be_init.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -989,7 +1052,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_produce.o .shobj/be_produce.so: be_produce.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -1027,7 +1091,8 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
.obj/be_args.o .shobj/be_args.so: be_args.cpp ../include/idl.h ../include/intlmacros.h \
../include/idl_narrow.h ../include/idl_defines.h ../include/idl_fwd.h \
../include/idl_bool.h ../include/utl_string.h \
@@ -1065,6 +1130,72 @@ CPPFLAGS += -I../include -I../be_include -I. -DCPP_LOCATION=\"$(CXX)\" -DIDL_CFE
../be_include/be_union_branch.h ../be_include/be_union_label.h \
../be_include/be_constant.h ../be_include/be_enum_val.h \
../be_include/be_array.h ../be_include/be_sequence.h \
- ../be_include/be_string.h ../be_include/be_typedef.h
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
+.obj/be_helper.o .shobj/be_helper.so: be_helper.cpp /pkg/gnu/lib/g++-include/iostream.h \
+ /pkg/gnu/lib/g++-include/fstream.h \
+ $(WRAPPER_ROOT)/ace/ACE.h \
+ $(WRAPPER_ROOT)/ace/OS.h \
+ $(WRAPPER_ROOT)/ace/config.h \
+ $(WRAPPER_ROOT)/ace/stdcpp.h \
+ $(WRAPPER_ROOT)/ace/OS.i \
+ $(WRAPPER_ROOT)/ace/Trace.h \
+ $(WRAPPER_ROOT)/ace/Log_Msg.h \
+ $(WRAPPER_ROOT)/ace/Log_Record.h \
+ $(WRAPPER_ROOT)/ace/Log_Priority.h \
+ $(WRAPPER_ROOT)/ace/Log_Record.i \
+ $(WRAPPER_ROOT)/ace/ACE.i \
+ $(WRAPPER_ROOT)/ace/Singleton.h \
+ $(WRAPPER_ROOT)/ace/Synch.h \
+ $(WRAPPER_ROOT)/ace/SV_Semaphore_Complex.h \
+ $(WRAPPER_ROOT)/ace/SV_Semaphore_Simple.h \
+ $(WRAPPER_ROOT)/ace/SV_Semaphore_Simple.i \
+ $(WRAPPER_ROOT)/ace/SV_Semaphore_Complex.i \
+ $(WRAPPER_ROOT)/ace/Synch.i \
+ $(WRAPPER_ROOT)/ace/Synch_T.h \
+ $(WRAPPER_ROOT)/ace/Event_Handler.h \
+ $(WRAPPER_ROOT)/ace/Event_Handler.i \
+ $(WRAPPER_ROOT)/ace/Synch_T.i \
+ $(WRAPPER_ROOT)/ace/Thread.h \
+ $(WRAPPER_ROOT)/ace/Thread.i \
+ $(WRAPPER_ROOT)/ace/Singleton.i \
+ ../include/idl.h ../include/intlmacros.h ../include/idl_narrow.h \
+ ../include/idl_defines.h ../include/idl_fwd.h ../include/idl_bool.h \
+ ../include/utl_string.h ../include/utl_identifier.h ../include/ast.h \
+ ../include/utl_scoped_name.h ../include/ast_decl.h \
+ ../include/ast_expression.h ../include/utl_scope.h \
+ ../include/ast_type.h ../include/ast_concrete_type.h \
+ ../include/ast_predefined_type.h ../include/ast_module.h \
+ ../include/ast_root.h ../include/ast_interface.h \
+ ../include/ast_interface_fwd.h ../include/ast_structure.h \
+ ../include/ast_exception.h ../include/ast_enum.h \
+ ../include/ast_operation.h ../include/utl_list.h \
+ ../include/ast_field.h ../include/ast_argument.h \
+ ../include/ast_attribute.h ../include/ast_union.h \
+ ../include/ast_union_branch.h ../include/ast_union_label.h \
+ ../include/ast_constant.h ../include/ast_enum_val.h \
+ ../include/ast_array.h ../include/ast_sequence.h \
+ ../include/ast_string.h ../include/ast_typedef.h \
+ ../include/utl_strlist.h ../include/utl_exprlist.h \
+ ../include/ast_generator.h ../include/util.h ../include/utl_stack.h \
+ ../include/utl_idlist.h ../include/utl_exceptlist.h \
+ ../include/utl_namelist.h ../include/utl_labellist.h \
+ ../include/utl_decllist.h ../include/idl_global.h \
+ ../include/utl_error.h ../include/utl_indenter.h \
+ ../include/idl_extern.h ../include/fe_extern.h ../include/be_extern.h \
+ ../include/drv_extern.h ../include/ast_extern.h \
+ ../include/nr_extern.h ../include/global_extern.h ../be_include/be.h \
+ ../be_include/be_generator.h ../be_include/be_predefined_type.h \
+ ../be_include/be_module.h ../be_include/be_interface.h \
+ ../be_include/be_interface_fwd.h ../be_include/be_structure.h \
+ ../be_include/be_exception.h ../be_include/be_expression.h \
+ ../be_include/be_enum.h ../be_include/be_operation.h \
+ ../be_include/be_field.h ../be_include/be_argument.h \
+ ../be_include/be_attribute.h ../be_include/be_union.h \
+ ../be_include/be_union_branch.h ../be_include/be_union_label.h \
+ ../be_include/be_constant.h ../be_include/be_enum_val.h \
+ ../be_include/be_array.h ../be_include/be_sequence.h \
+ ../be_include/be_string.h ../be_include/be_typedef.h \
+ ../be_include/be_root.h ../be_include/be_helper.h
# IF YOU PUT ANYTHING HERE IT WILL GO AWAY
diff --git a/TAO/TAO_IDL/be/be_generator.cpp b/TAO/TAO_IDL/be/be_generator.cpp
index 816d6830f22..9bd8a0c22e9 100644
--- a/TAO/TAO_IDL/be/be_generator.cpp
+++ b/TAO/TAO_IDL/be/be_generator.cpp
@@ -92,6 +92,16 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
*/
/*
+ * Construct a be_root node (a node representing the root of an AST of BE nodes)
+ */
+AST_Root *
+be_generator::create_root(UTL_ScopedName *n,
+ UTL_StrList *p)
+{
+ return new be_root(n, p);
+}
+
+/*
* Create a BE_PredefinedType node
*/
AST_PredefinedType *
diff --git a/TAO/TAO_IDL/be/be_helper.cpp b/TAO/TAO_IDL/be/be_helper.cpp
index e5d5c7ef7cc..3e19dc16685 100644
--- a/TAO/TAO_IDL/be/be_helper.cpp
+++ b/TAO/TAO_IDL/be/be_helper.cpp
@@ -1,9 +1,65 @@
-#include "ace/ACE.h"
-#include "ace/OS.h"
#include "idl.h"
#include "idl_extern.h"
#include "be.h"
+/* BE global Data */
+TAO_BE_Params::TAO_BE_Params()
+ : pd_client_header(0),
+ pd_client_stubs(0),
+ pd_server_header(0),
+ pd_server_skeletons(0)
+{
+}
+
+// set the client header stream
+void TAO_BE_Params::client_header(streambuf *sbuf)
+{
+ this->pd_client_header = sbuf;
+}
+
+// get the client header stream
+streambuf* TAO_BE_Params::client_header()
+{
+ return this->pd_client_header;
+}
+
+// set the client stub stream
+void TAO_BE_Params::client_stubs(streambuf* f)
+{
+ this->pd_client_stubs = f;
+}
+
+// get the client stubs stream
+streambuf* TAO_BE_Params::client_stubs()
+{
+ return this->pd_client_stubs;
+}
+
+// set the server header stream
+void TAO_BE_Params::server_header(streambuf* f)
+{
+ this->pd_server_header = f;
+}
+
+// get the server header stream
+streambuf* TAO_BE_Params::server_header()
+{
+ return this->pd_server_header;
+}
+
+// set the server skeletons stream
+void TAO_BE_Params::server_skeletons(streambuf* f)
+{
+ this->pd_server_skeletons = f;
+}
+
+// get the server skeletons stream
+streambuf* TAO_BE_Params::server_skeletons()
+{
+ return this->pd_server_skeletons;
+}
+
+/************ Helper functions **************/
const char* be_get_client_hdr_fname()
{
String *s;
@@ -23,7 +79,7 @@ const char* be_get_client_hdr_fname()
return fname;
}
-const char* be_get_client_impl_fname()
+const char* be_get_client_stub_fname()
{
String *s;
char *base;
@@ -61,7 +117,7 @@ const char* be_get_server_hdr_fname()
return fname;
}
-const char* be_get_server_impl_fname()
+const char* be_get_server_skeleton_fname()
{
String *s;
char *base;
diff --git a/TAO/TAO_IDL/be/be_interface.cpp b/TAO/TAO_IDL/be/be_interface.cpp
index 391ffe3284a..529b1571ab0 100644
--- a/TAO/TAO_IDL/be/be_interface.cpp
+++ b/TAO/TAO_IDL/be/be_interface.cpp
@@ -19,6 +19,7 @@ be_interface::be_interface(UTL_ScopedName *n, AST_Interface **ih, long nih,
void be_interface::gen_client_header()
{
+#if 0
if (idl_global->in_main_file())
{
// if we are defined in the main file, then generate the code
@@ -40,6 +41,19 @@ void be_interface::gen_client_header()
idl_global->indent()->skip_to(o);
o << "}";
}
+#endif
+}
+
+void be_interface::gen_client_stubs()
+{
+}
+
+void be_interface::gen_server_header()
+{
+}
+
+void be_interface::gen_server_skeletons()
+{
}
// Narrowing
diff --git a/TAO/TAO_IDL/be/be_produce.cpp b/TAO/TAO_IDL/be/be_produce.cpp
index 345c45b59b8..40911a4db82 100644
--- a/TAO/TAO_IDL/be/be_produce.cpp
+++ b/TAO/TAO_IDL/be/be_produce.cpp
@@ -78,6 +78,41 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
void
BE_produce()
{
+
+#if 0
+ // let us print all the global values
+ cout << "filename is " << endl;
+ idl_global->filename()->dump(cout);
+ cout << endl;
+ cout << "main filename is " << endl;
+ idl_global->main_filename()->dump(cout);
+ cout << endl;
+ cout << "real filename is " << endl;
+ idl_global->real_filename()->dump(cout);
+ cout << endl;
+ cout << "stripped filename is " << endl;
+ idl_global->stripped_filename()->dump(cout);
+ cout << endl;
+ cout << "IDL source filename is " << endl;
+ idl_global->idl_src_file()->dump(cout);
+ cout << endl;
+ cout << "prog_name is " << idl_global->prog_name() << endl;
+#endif
+ be_root *root; // root of the AST made up of BE nodes
+ AST_Decl *d = idl_global->root();
+ root = be_root::narrow_from_decl(d);
+ if (root == NULL)
+ {
+ cerr << "No root" << endl;
+ BE_abort();
+ }
+
+ // start the code generation process
+ if (root->gen_idl2cplusplus_mapping() == -1)
+ {
+ cerr << "Mapping process failed" << endl;
+ BE_abort();
+ }
}
/*
@@ -86,4 +121,6 @@ BE_produce()
void
BE_abort()
{
+ cerr << "Fatal Error" << endl;
+ exit (1);
}
diff --git a/TAO/TAO_IDL/be/be_root.cpp b/TAO/TAO_IDL/be/be_root.cpp
index 48725633a86..2de6805b99c 100644
--- a/TAO/TAO_IDL/be/be_root.cpp
+++ b/TAO/TAO_IDL/be/be_root.cpp
@@ -2,3 +2,155 @@
#include "idl_extern.h"
#include "be.h"
+// Default Constructor
+be_root::be_root()
+{
+}
+
+// Constructor
+be_root::be_root(UTL_ScopedName *n, UTL_StrList *p)
+ : AST_Root(n, p),
+ AST_Decl(AST_Decl::NT_module, n, p),
+ UTL_Scope(AST_Decl::NT_module)
+{
+}
+
+// Generates the IDL to C++ mapping
+// Generates the client-side header information for the root
+long be_root::gen_idl2cplusplus_mapping()
+{
+ fstream f; // fstream instance
+ TAO_BE_Params *params = TAO_BE_PARAMS::instance();
+
+ // Open the client header file for writing
+ f.open(be_get_client_hdr_fname(), ios::out);
+ if (f.fail())
+ {
+ return -1;
+ }
+ params->client_header(f.rdbuf());
+
+ // generate client header
+ if (this->gen_client_header() < 0)
+ {
+ return -1;
+ }
+ f.close();
+
+ // Open the server header file for writing
+ f.open(be_get_server_hdr_fname(), ios::out);
+ if (f.fail())
+ {
+ return -1;
+ }
+ params->server_header(f.rdbuf());
+
+ // generate the server header
+ if (this->gen_server_header() < 0)
+ {
+ return -1;
+ }
+ f.close();
+
+ // Open the client stubs file for writing
+ f.open(be_get_client_stub_fname(), ios::out);
+ params->client_stubs(f.rdbuf());
+
+ // generate client side stubs
+ if (this->gen_client_stubs() < 0)
+ {
+ return -1;
+ }
+ f.close();
+
+ // Open the server skeleton file for writing
+ f.open(be_get_server_skeleton_fname(), ios::out);
+ params->server_header(f.rdbuf());
+
+ // generate server side skeletons
+ if (this->gen_server_skeletons() < 0)
+ {
+ return -1;
+ }
+ f.close();
+
+ return 0;
+}
+
+// generate client header
+long be_root::gen_client_header()
+{
+ TAO_BE_Params *params = TAO_BE_PARAMS::instance(); // holds the buffer
+ // pointing to the output
+ // stream
+ ostream o(params->client_header()); // get a handle to the output stream
+
+ // check for failure
+ if (o.fail())
+ {
+ return -1;
+ }
+
+ // generate the #if !defined, #define statement
+
+ return 0;
+}
+
+// Generates the client-side stubs for the root
+long be_root::gen_client_stubs()
+{
+ TAO_BE_Params *params = TAO_BE_PARAMS::instance(); // holds the buffer
+ // pointing to the output
+ // stream
+ ostream o(params->client_stubs()); // get a handle to the output stream
+
+ // check for failure
+ if (o.fail())
+ {
+ return -1;
+ }
+
+ return 0;
+}
+
+// Generates the server-side header information for the root
+long be_root::gen_server_header()
+{
+ TAO_BE_Params *params = TAO_BE_PARAMS::instance(); // holds the buffer
+ // pointing to the output
+ // stream
+ ostream o(params->server_header()); // get a handle to the output stream
+
+ // check for failure
+ if (o.fail())
+ {
+ return -1;
+ }
+
+ return 0;
+}
+
+// Generates the server-side skeletons for the root
+long be_root::gen_server_skeletons()
+{
+ TAO_BE_Params *params = TAO_BE_PARAMS::instance(); // holds the buffer
+ // pointing to the output
+ // stream
+ ostream o(params->server_skeletons()); // get a handle to the output stream
+
+ // check for failure
+ if (o.fail())
+ {
+ return -1;
+ }
+
+ return 0;
+}
+
+
+/*
+ * Narrowing methods
+ */
+IMPL_NARROW_METHODS1(be_root, AST_Root)
+IMPL_NARROW_FROM_DECL(be_root)
+IMPL_NARROW_FROM_SCOPE(be_root)
diff --git a/TAO/TAO_IDL/be_include/be.h b/TAO/TAO_IDL/be_include/be.h
index f05b559e07d..eb2ebff48f7 100644
--- a/TAO/TAO_IDL/be_include/be.h
+++ b/TAO/TAO_IDL/be_include/be.h
@@ -97,6 +97,7 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
#include "be_sequence.h" // class BE_Sequence
#include "be_string.h" // class BE_String
#include "be_typedef.h" // class BE_Typedef
+#include "be_root.h" // class BE_Root
#include "be_helper.h" // helper functions
#endif // _BE_BE_HH
diff --git a/TAO/TAO_IDL/be_include/be_generator.h b/TAO/TAO_IDL/be_include/be_generator.h
index 2f02df872b4..c22aa9947a3 100644
--- a/TAO/TAO_IDL/be_include/be_generator.h
+++ b/TAO/TAO_IDL/be_include/be_generator.h
@@ -82,6 +82,11 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
class be_generator : public AST_Generator {
public:
+ virtual AST_Root *create_root(UTL_ScopedName *n,
+ UTL_StrList *p);
+ // Create a node representing a module which is the root of an AST made up of
+ // BE nodes
+
// Operations
virtual AST_PredefinedType
*create_predefined_type(AST_PredefinedType::PredefinedType t,
diff --git a/TAO/TAO_IDL/be_include/be_helper.h b/TAO/TAO_IDL/be_include/be_helper.h
index cc2acb4aada..039dc60ee3f 100644
--- a/TAO/TAO_IDL/be_include/be_helper.h
+++ b/TAO/TAO_IDL/be_include/be_helper.h
@@ -1,9 +1,84 @@
+// ============================================================================
+//
+// = LIBRARY
+// TAO IDL
+//
+// = FILENAME
+// be_helper.h
+//
+// = DESCRIPTION
+// Helper utilities and global singleton "params" class
+//
+// = AUTHOR
+// Aniruddha Gokhale
+//
+// ============================================================================
+
#if !defined (TAO_BE_HELPER_H)
#define TAO_BE_HELPER_H
+#include "iostream.h"
+#include "fstream.h"
+#include "ace/ACE.h"
+#include "ace/OS.h"
+#include "ace/Singleton.h"
+#include "ace/Synch.h"
+
+class TAO_BE_Params
+// = TITLE
+// Holds global parameters for the Back End
+//
+// = DESCRIPTION
+//
+{
+public:
+ TAO_BE_Params();
+ // Constructor
+
+ void client_header(streambuf *sbuf);
+ // set the client header stream
+
+ streambuf* client_header();
+ // get the client header stream
+
+ void client_stubs(streambuf* f);
+ // set the client stub stream
+
+ streambuf* client_stubs();
+ // get the client stubs stream
+
+ void server_header(streambuf* f);
+ // set the server header stream
+
+ streambuf* server_header();
+ // get the server header stream
+
+ void server_skeletons(streambuf* f);
+ // set the server skeletons stream
+
+ streambuf* server_skeletons();
+ // get the server skeletons stream
+private:
+ streambuf *pd_client_header;
+ // client header stream
+
+ streambuf *pd_client_stubs;
+ // client stub file stream
+
+ streambuf *pd_server_header;
+ // server header stream
+
+ streambuf *pd_server_skeletons;
+ // server skeleton stream
+};
+
+typedef ACE_Singleton<TAO_BE_Params,ACE_Thread_Mutex> TAO_BE_PARAMS;
+// Singleton instance of BE parameters
+
const char* be_get_client_hdr_fname();
-const char* be_get_client_impl_fname();
+const char* be_get_client_stub_fname();
const char* be_get_server_hdr_fname();
-const char* be_get_server_impl_fname();
+const char* be_get_server_skeleton_fname();
+
#endif
diff --git a/TAO/TAO_IDL/be_include/be_root.h b/TAO/TAO_IDL/be_include/be_root.h
index 6ab39f71ffd..7a15cb58080 100644
--- a/TAO/TAO_IDL/be_include/be_root.h
+++ b/TAO/TAO_IDL/be_include/be_root.h
@@ -1,8 +1,59 @@
+// ============================================================================
+//
+// = LIBRARY
+// TAO IDL
+//
+// = FILENAME
+// be_root.h
+//
+// = DESCRIPTION
+// Extension of class AST_Root that provides additional means for C++
+// mapping of an interface.
+//
+// = AUTHOR
+// Copyright 1994-1995 by Sun Microsystems, Inc.
+// and
+// Aniruddha Gokhale
+//
+// ============================================================================
+
#if !defined (TAO_BE_ROOT_H)
#define TAO_BE_ROOT_H
class be_root : public virtual AST_Root
+ // = TITLE
+ // The back end extension of the AST_Root class
+ //
+ // = DESCRIPTION
+ //
{
+public:
+ // Operations
+ be_root();
+ // Default constructor
+
+ be_root(UTL_ScopedName *n, UTL_StrList *p);
+ // Constructor that sets its scoped name <n>, and any pragmas <p>
+
+ long gen_idl2cplusplus_mapping();
+ // generates the IDL to C++ mapping
+
+ long gen_client_header();
+ // Generates the client-side header information for the interface
+
+ long gen_client_stubs();
+ // Generates the client-side stubs for the interface
+
+ long gen_server_header();
+ // Generates the server-side header information for the interface
+
+ long gen_server_skeletons();
+ // Generates the server-side skeletons for the interface
+
+ // Narrowing
+ DEF_NARROW_METHODS1(be_root, AST_root);
+ DEF_NARROW_FROM_DECL(be_root);
+ DEF_NARROW_FROM_SCOPE(be_root);
};
#endif
diff --git a/TAO/TAO_IDL/driver/Makefile b/TAO/TAO_IDL/driver/Makefile
index 1132bfe0804..25865cfc3d1 100644
--- a/TAO/TAO_IDL/driver/Makefile
+++ b/TAO/TAO_IDL/driver/Makefile
@@ -31,7 +31,7 @@ LDLIBS = -ldrv
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
diff --git a/TAO/TAO_IDL/fe/Makefile b/TAO/TAO_IDL/fe/Makefile
index 50116229499..246c7cc311c 100644
--- a/TAO/TAO_IDL/fe/Makefile
+++ b/TAO/TAO_IDL/fe/Makefile
@@ -34,7 +34,7 @@ LDLIBS = -lfe
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
@@ -58,6 +58,7 @@ YACC = yacc
LEX = lex
YFLAGS = -t -d
LFLAGS = -t
+
# Create the parser and lexer
y.tab.hh y.tab.cpp: idl.yy
@-$(RM) $@
@@ -277,6 +278,6 @@ lex.yy.cpp: idl.ll y.tab.h
../include/drv_extern.h ../include/ast_extern.h \
../include/nr_extern.h ../include/global_extern.h \
../include/fe_private.h ../include/fe_interface_header.h \
- ../include/fe_declarator.h
+ ../include/fe_declarator.h y.tab.h
# IF YOU PUT ANYTHING HERE IT WILL GO AWAY
diff --git a/TAO/TAO_IDL/include/idl_global.h b/TAO/TAO_IDL/include/idl_global.h
index e3d115bfbc4..1c19e47bc4b 100644
--- a/TAO/TAO_IDL/include/idl_global.h
+++ b/TAO/TAO_IDL/include/idl_global.h
@@ -286,6 +286,7 @@ public:
AST_PredefinedType::PredefinedType
);
+ /**************** Added to serve the back end *************/
virtual String *idl_src_file();
// returns the IDL source file being copiled
diff --git a/TAO/TAO_IDL/narrow/Makefile b/TAO/TAO_IDL/narrow/Makefile
index 443bf918e50..44c37664751 100644
--- a/TAO/TAO_IDL/narrow/Makefile
+++ b/TAO/TAO_IDL/narrow/Makefile
@@ -25,7 +25,7 @@ LDLIBS = -lnarrow
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
diff --git a/TAO/TAO_IDL/util/Makefile b/TAO/TAO_IDL/util/Makefile
index e297ac70fdf..737f9595797 100644
--- a/TAO/TAO_IDL/util/Makefile
+++ b/TAO/TAO_IDL/util/Makefile
@@ -40,7 +40,7 @@ LDLIBS = -lutil
LIBS = -lACE
VLDLIBS = $(LDLIBS:%=%$(VAR))
-BUILD = $(VSHLIB) $(VLIB)
+BUILD = $(VSHLIB) #$(VLIB)
#----------------------------------------------------------------------------
diff --git a/TAO/TAO_IDL/util/utl_global.cpp b/TAO/TAO_IDL/util/utl_global.cpp
index f7632e3bc68..90d8b046bc8 100644
--- a/TAO/TAO_IDL/util/utl_global.cpp
+++ b/TAO/TAO_IDL/util/utl_global.cpp
@@ -464,3 +464,15 @@ IDL_GlobalData::PredefinedTypeToExprType(AST_PredefinedType::PredefinedType pt)
return AST_Expression::EV_any;
}
}
+
+// returns the IDL source file being copiled
+String* IDL_GlobalData::idl_src_file()
+{
+ return this->pd_idl_src_file;
+}
+
+// set the source IDL file that is being parsed
+void IDL_GlobalData::idl_src_file(String *s)
+{
+ this->pd_idl_src_file = s;
+}
diff --git a/TAO/TAO_IDL/be_include/be_interface.h b/TAO/TAO_IDL/be_include/be_interface.h
index 0453c841075..9cf35a04967 100644
--- a/TAO/TAO_IDL/be_include/be_interface.h
+++ b/TAO/TAO_IDL/be_include/be_interface.h
@@ -43,14 +43,14 @@ public:
void gen_client_header();
// Generates the client-side header information for the interface
- void gen_client_impl();
- // Generates the client-side implementation for the interface
+ void gen_client_stubs();
+ // Generates the client-side stubs for the interface
void gen_server_header();
// Generates the server-side header information for the interface
- void gen_server_impl();
- // Generates the server-side implementation for the interface
+ void gen_server_skeletons();
+ // Generates the server-side skeletons for the interface
// Narrowing
DEF_NARROW_METHODS1(be_interface, AST_Interface);